==> haskell-process-extras-0.7.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.1
id: process-extras-0.7.1-FRd7vV29JoIGZUisXpzsWY
key: process-extras-0.7.1-FRd7vV29JoIGZUisXpzsWY
license: MIT
maintainer: David Fox <dsf@seereason.com>
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
author: David Lazar, Bas van Dijk, David Fox
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Lazy
    System.Process.Text.Builder
hidden-modules: Utils
abi: 33514975d96228bff65183cb5fd738e6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/process-extras-0.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/process-extras-0.7.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/process-extras-0.7.1
hs-libraries: HSprocess-extras-0.7.1-FRd7vV29JoIGZUisXpzsWY
depends:
    ListLike-4.5-4reYfJzrhhCJymGO6NrJ5X base-4.9.0.0
    bytestring-0.10.8.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    deepseq-1.4.2.0 generic-deriving-1.11.1-A3LIGwpr65P8ydjYiAp7Zd
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM process-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: process-extras
version: 0.7.1
id: process-extras-0.7.1-7TqC8vhOIIK2vBrs5N6oBr
key: process-extras-0.7.1-7TqC8vhOIIK2vBrs5N6oBr
license: MIT
maintainer: David Fox <dsf@seereason.com>
homepage: https://github.com/seereason/process-extras
synopsis: Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.
category: System
author: David Lazar, Bas van Dijk, David Fox
exposed: True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Lazy
    System.Process.Text.Builder
hidden-modules: Utils
abi: 110ee7fd9697f4b5928c03ba6fe8665b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/process-extras-0.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/process-extras-0.7.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/process-extras-0.7.1
hs-libraries: HSprocess-extras-0.7.1-7TqC8vhOIIK2vBrs5N6oBr
depends:
    ListLike-4.5.1-1tkcvNyj54E71yiOvznO5K base-4.9.0.0
    bytestring-0.10.8.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    deepseq-1.4.2.0 generic-deriving-1.11.1-A3LIGwpr65P8ydjYiAp7Zd
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM process-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-process-extras/html/process-extras.haddock
haddock-html: /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
